@@ -1,5 +1,5 @@
 """
-    Dummy conftest.py for bbox.
+    Dummy conftest.py for bbox_utils.
 
     If you don't know what this is for, just leave it empty.
     Read more about conftest.py under:
